@@ -1,6 +1,6 @@
 package Statocles::App;
 # ABSTRACT: Base class for Statocles applications
-$Statocles::App::VERSION = '0.033';
+$Statocles::App::VERSION = '0.034';
 use Statocles::Base 'Class';
 
 
@@ -10,6 +10,13 @@ has site => (
     isa => InstanceOf['Statocles::Site'],
 );
 
+
+has data => (
+    is => 'ro',
+    isa => HashRef,
+    default => sub { {} },
+);
+
 1;
 
 __END__
@@ -22,7 +29,7 @@ Statocles::App - Base class for Statocles applications
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 DESCRIPTION
 
@@ -36,6 +43,12 @@ directly, if desired).
 
 The site this app is part of.
 
+=head2 data
+
+A hash of arbitrary data available to theme templates. This is a good place to
+put extra structured data like social network links or make easy customizations
+to themes like header image URLs.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
