@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.033';
+$Statocles::App::Blog::VERSION = '0.034';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -49,7 +49,6 @@ has _post_pages => (
 
 
 our $default_post = {
-    author => undef,
     tags => undef,
     content => <<'ENDCONTENT',
 Markdown content goes here.
@@ -169,10 +168,10 @@ sub post_pages {
 
         my @tags;
         for my $tag ( @{ $doc->tags } ) {
-            push @tags, {
-                title => $tag,
+            push @tags, Statocles::Link->new(
+                text => $tag,
                 href => $self->_tag_url( $tag ),
-            };
+            );
         }
 
         push @pages, Statocles::Page::Document->new(
@@ -194,12 +193,12 @@ sub post_pages {
 
 my %FEEDS = (
     rss => {
-        title => 'RSS',
+        text => 'RSS',
         type => 'application/rss+xml',
         template => 'index.rss',
     },
     atom => {
-        title => 'Atom',
+        text => 'Atom',
         type => 'application/atom+xml',
         template => 'index.atom',
     },
@@ -245,16 +244,16 @@ sub index {
             template => $self->site->theme->template( blog => $FEEDS{$feed}{template} ),
         );
         push @feed_pages, $page;
-        push @feed_links, {
-            title => $FEEDS{ $feed }{ title },
-            href => $page->path,
+        push @feed_links, Statocles::Link->new(
+            text => $FEEDS{ $feed }{ text },
+            href => $page->path->stringify,
             type => $page->type,
-        };
+        );
     }
 
     # Add the feeds to all the pages
     for my $page ( @pages ) {
-        $page->links->{feed} = \@feed_links;
+        $page->_links->{feed} = \@feed_links;
     }
 
     return ( @pages, @feed_pages );
@@ -294,16 +293,16 @@ sub tag_pages {
                 template => $self->site->theme->template( blog => $FEEDS{$feed}{template} ),
             );
             push @feed_pages, $page;
-            push @feed_links, {
-                title => $FEEDS{ $feed }{ title },
-                href => $page->path,
+            push @feed_links, Statocles::Link->new(
+                text => $FEEDS{ $feed }{ text },
+                href => $page->path->stringify,
                 type => $page->type,
-            };
+            );
         }
 
         # Add the feeds to all the pages
         for my $page ( @tag_pages ) {
-            $page->links->{feed} = \@feed_links;
+            $page->_links->{feed} = \@feed_links;
         }
 
         push @pages, @tag_pages, @feed_pages;
@@ -326,7 +325,7 @@ sub pages {
 sub tags {
     my ( $self ) = @_;
     my %tagged_docs = $self->_tag_docs( @{ $self->_post_pages } );
-    return map {; { title => $_, href => $self->_tag_url( $_ ), } }
+    return map {; Statocles::Link->new( text => $_, href => $self->_tag_url( $_ ) ) }
         sort keys %tagged_docs
 }
 
@@ -359,7 +358,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 DESCRIPTION
 
@@ -456,10 +455,10 @@ Get all the L<pages|Statocles::Page> for this application.
 
 =head2 tags()
 
-Get a set of hashrefs suitable for creating a list of tag links. The hashrefs
-contain the following keys:
+Get a set of L<link objects|Statocles::Link> suitable for creating a list of
+tag links. The common attributes are:
 
-    title => 'The tag text'
+    text => 'The tag text'
     href => 'The URL to the tag page'
 
 =head1 THEME
