@@ -1,6 +1,6 @@
 package Statocles::Base;
 # ABSTRACT: Base module for Statocles modules
-$Statocles::Base::VERSION = '0.033';
+$Statocles::Base::VERSION = '0.034';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -22,7 +22,7 @@ our @IMPORT_MODULES = (
 
 my @class_modules = (
     'Types::Standard' => [qw( :all )],
-    'Types::Path::Tiny' => [qw( Path AbsPath )],
+    'Types::Path::Tiny' => [qw( Path AbsPath Dir )],
     'Statocles::Types' => [qw( :all )],
 );
 
@@ -31,7 +31,7 @@ our %IMPORT_BUNDLES = (
         qw( Test::More Test::Deep Test::Differences Test::Exception ),
         'Dir::Self' => [qw( __DIR__ )],
         'Path::Tiny' => [qw( path tempdir cwd )],
-        'Statocles::Test' => [qw( test_constructor test_pages )],
+        'Statocles::Test' => [qw( test_constructor test_pages build_test_site )],
         'Statocles::Site',
         sub { $Statocles::VERSION = 0.001; return }, # Set version normally done via dzil
     ],
@@ -60,7 +60,7 @@ Statocles::Base - Base module for Statocles modules
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
