@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.033';
+$Statocles::Command::VERSION = '0.034';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through );
@@ -161,13 +161,9 @@ sub main {
             $index = $base . $index;
         }
 
-        unshift @{ $self->static->paths },
-            $self->site->build_store->path,
-            # Add the deploy store for non-Statocles content
-            # This won't work in certain situations, like a Git repo on another branch, but
-            # this is convenience until we can track image directories and other non-generated
-            # content.
-            $self->site->deploy_store->path;
+        # Add the build dir to the list of static paths for mojolicious to
+        # search
+        unshift @{ $self->static->paths }, $self->site->build_store->path;
 
         # Watch for filesystem events and rebuild the site Right now this only
         # works on OSX. We should spin this off into Mojo::IOLoop::FSEvents and
@@ -281,7 +277,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
