@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.033';
+$Statocles::Document::VERSION = '0.034';
 use Statocles::Base 'Class';
 
 
@@ -44,17 +44,9 @@ has tags => (
 
 has links => (
     is => 'rw',
-    isa => HashRef[ArrayRef[HashRef]],
+    isa => LinkHash,
     default => sub { +{} },
-    coerce => sub {
-        # Normalize to arrays
-        for my $category ( keys %{$_[0]} ) {
-            if ( ref $_[0]{$category} ne 'ARRAY' ) {
-                $_[0]{$category} = [ $_[0]{$category} ];
-            }
-        }
-        return $_[0];
-    },
+    coerce => LinkHash->coercion,
 );
 
 
@@ -75,7 +67,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 DESCRIPTION
 
@@ -116,11 +108,13 @@ Related links for this document. Links are used to build relationships
 to other web addresses. Link categories are named based on their
 relationship.
 
-    crosspost - The same document posted to another web site
+    alternate - The same document posted to another web site
 
-Each category contains an arrayref of hashrefs with the following keys:
+Each category contains an arrayref of hashrefs of L<link objects|Statocles::Link>.
+See the L<Statocles::Link|Statocles::Link> documentation for a full list of
+supported attributes. The most common attributes are:
 
-    title - The title of the link
+    text - The text of the link
     href - The URL for the link
 
 =head2 last_modified
