@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.033';
+$Statocles::Page::Document::VERSION = '0.034';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Text::Markdown;
@@ -14,10 +14,32 @@ has document => (
 );
 
 
-has tags => (
+has title => (
     is => 'ro',
-    isa => ArrayRef[HashRef],
+    isa => Str,
+    lazy => 1,
+    default => sub { $_[0]->document->title },
+);
+
+
+has author => (
+    is => 'ro',
+    isa => Str,
+    lazy => 1,
+    default => sub { $_[0]->document->author || '' },
+);
+
+
+has _tags => (
+    is => 'ro',
+    isa => LinkArray,
     default => sub { [] },
+    coerce => LinkArray->coercion,
+    init_arg => 'tags',
+);
+
+has '+_links' => (
+    default => sub { $_[0]->document->links },
 );
 
 
@@ -51,6 +73,12 @@ sub last_modified {
     return $self->document->last_modified;
 }
 
+
+sub tags {
+    my ( $self ) = @_;
+    return @{ $self->_tags };
+}
+
 1;
 
 __END__
@@ -63,7 +91,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 DESCRIPTION
 
@@ -75,12 +103,20 @@ This page class takes a single L<document|Statocles::Document> and renders it as
 
 The L<document|Statocles::Document> this page will render.
 
+=head2 title
+
+The title of the page.
+
+=head2 author
+
+The author of the page.
+
 =head2 tags
 
-The tag links for this document. An array of link hashes with the following
-keys:
+The tag links for this document. An array of L<link objects|Statocles::Link>. The
+most important attributes are:
 
-    title   - The title of the link
+    text    - The text of the link
     href    - The page of the link
 
 =head1 METHODS
@@ -103,6 +139,10 @@ sections.
 Get the last modified date of this page by checking the document or using the page's
 publish date.
 
+=head2 tags()
+
+Get the list of tags for this page.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
