@@ -1,7 +1,8 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.033';
+$Statocles::Site::VERSION = '0.034';
 use Statocles::Base 'Class';
+use Scalar::Util qw( blessed );
 use Mojo::URL;
 use Mojo::DOM;
 use Mojo::Log;
@@ -41,10 +42,12 @@ has index => (
 );
 
 
-has nav => (
+has _nav => (
     is => 'ro',
-    isa => HashRef[ArrayRef[HashRef[Str]]],
+    isa => LinkHash,
+    coerce => LinkHash->coercion,
     default => sub { {} },
+    init_arg => 'nav',
 );
 
 
@@ -56,12 +59,27 @@ has build_store => (
 );
 
 
-has deploy_store => (
+has _deploy => (
     is => 'ro',
-    isa => Store,
-    lazy => 1,
-    default => sub { $_[0]->build_store },
-    coerce => Store->coercion,
+    isa => ConsumerOf['Statocles::Deploy'],
+    required => 1,
+    init_arg => 'deploy',
+    coerce => sub {
+        if ( ( blessed $_[0] && $_[0]->isa( 'Path::Tiny' ) ) || !ref $_[0] ) {
+            require Statocles::Deploy::File;
+            return Statocles::Deploy::File->new(
+                path => $_[0],
+            );
+        }
+        return $_[0];
+    },
+);
+
+
+has data => (
+    is => 'ro',
+    isa => HashRef,
+    default => sub { {} },
 );
 
 
@@ -74,6 +92,13 @@ has log => (
     },
 );
 
+# The current deploy we're writing to
+has _write_deploy => (
+    is => 'rw',
+    isa => ConsumerOf['Statocles::Deploy'],
+    clearer => '_clear_write_deploy',
+);
+
 
 sub BUILD {
     my ( $self ) = @_;
@@ -90,20 +115,16 @@ sub app {
 }
 
 
+sub nav {
+    my ( $self, $name ) = @_;
+    return $self->_nav->{ $name } ? @{ $self->_nav->{ $name } } : ();
+}
+
+
 sub build {
     my ( $self ) = @_;
-    $self->write( $self->build_store );
-}
 
-
-sub deploy {
-    my ( $self ) = @_;
-    $self->write( $self->deploy_store );
-}
-
-
-sub write {
-    my ( $self, $store ) = @_;
+    my $store = $self->build_store;
     my $apps = $self->apps;
     my @pages;
     my %args = (
@@ -116,6 +137,10 @@ sub write {
 
         my @app_pages = $app->pages;
         if ( $self->index eq $app_name ) {
+
+            die sprintf 'ERROR: Index app "%s" did not generate any pages' . "\n", $self->index
+                unless @app_pages;
+
             # Rename the app's page so that we don't get two pages with identical
             # content, which is bad for SEO
             $app_pages[0]->path( '/index.html' );
@@ -125,8 +150,12 @@ sub write {
     }
 
     # Rewrite page content to add base URL
-    my $base_path = Mojo::URL->new( $self->base_url )->path;
-    $base_path =~ s{/$}{};
+    my $base_url = $self->base_url;
+    if ( $self->_write_deploy ) {
+        $base_url = $self->_write_deploy->base_url || $base_url;
+    }
+    my $base_path = Mojo::URL->new( $base_url )->path;
+
     for my $page ( @pages ) {
         my $content = $page->render( %args );
 
@@ -157,12 +186,30 @@ sub write {
     # We should do more with this later...
     my $robots_tmpl = $self->theme->template( site => 'robots.txt' );
     $store->write_file( 'robots.txt', $robots_tmpl->render( site => $self ) );
+
+    # Add the theme
+    my $theme_iter = $self->theme->store->find_files();
+    while ( my $theme_file = $theme_iter->() ) {
+        my $fh = $self->theme->store->open_file( $theme_file );
+        $store->write_file( Path::Tiny->new( 'theme', $theme_file ), $fh );
+    }
+}
+
+
+sub deploy {
+    my ( $self ) = @_;
+    $self->_write_deploy( $self->_deploy );
+    $self->build;
+    $self->_deploy->deploy( $self->build_store );
+    $self->_clear_write_deploy;
 }
 
 
 sub url {
     my ( $self, $path ) = @_;
-    my $base = $self->base_url;
+    my $base    = $self->_write_deploy && $self->_write_deploy->base_url
+                ? $self->_write_deploy->base_url
+                : $self->base_url;
     # Remove the / from both sides of the join so we don't double up
     $base =~ s{/$}{};
     $path =~ s{^/}{};
@@ -181,7 +228,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
@@ -212,6 +259,8 @@ The site title, used in templates.
 
 The base URL of the site, including protocol and domain. Used mostly for feeds.
 
+This can be overridden by L<base_url in Deploy|Statocles::Deploy/base_url>.
+
 =head2 theme
 
 The L<theme|Statocles::Theme> for this site. All apps share the same theme.
@@ -255,11 +304,17 @@ The L<store|Statocles::Store> object to use for C<build()>. This is a workspace
 and will be rebuilt often, using the C<build> and C<daemon> commands. This is
 also the store the C<daemon> command reads to serve the site.
 
-=head2 deploy_store
+=head2 deploy
 
-The L<store|Statocles::Store> object to use for C<deploy()>. Defaults to L<build_store>.
-This is intended to be the production deployment of the site. A build gets promoted
-to production by using the C<deploy> command.
+The L<deploy object|Statocles::Deploy> to use for C<deploy()>. This is
+intended to be the production deployment of the site. A build gets promoted to
+production by using the C<deploy> command.
+
+=head2 data
+
+A hash of arbitrary data available to theme templates. This is a good place to
+put extra structured data like social network links or make easy customizations
+to themes like header image URLs.
 
 =head2 log
 
@@ -275,17 +330,22 @@ Register this site as the global site.
 
 Get the app with the given C<name>.
 
+=head2 nav( name )
+
+Get the list of links for the given nav. Each link is a L<Statocles::Link> object.
+
+    title - The title of the link
+    href - The href of the link
+
+If the named nav does not exist, returns an empty list.
+
 =head2 build
 
 Build the site in its build location
 
 =head2 deploy
 
-Write each application to its destination.
-
-=head2 write( store )
-
-Write the application to the given L<store|Statocles::Store>.
+Deploy the site to its destination.
 
 =head2 url( path )
 
