@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.033';
+$Statocles::Template::VERSION = '0.034';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -99,15 +99,16 @@ sub _include {
     }
 
     my $store = $self->store;
-    if ( $store->has_file( "$name.ep" ) ) {
-        my $inner_tmpl = __PACKAGE__->new(
-            path => "$name.ep",
-            content => $store->read_file( "$name.ep" ),
-            store => $store,
-        );
-        return $inner_tmpl->render( %$vars );
-    }
-    elsif ( $store->has_file( $name ) ) {
+    if ( $store->has_file( $name ) ) {
+        if ( $name =~ /[.]ep$/ ) {
+            my $inner_tmpl = __PACKAGE__->new(
+                path => "$name",
+                content => $store->read_file( "$name" ),
+                store => $store,
+            );
+            return $inner_tmpl->render( %$vars );
+        }
+
         return $store->read_file( $name );
     }
 
@@ -138,7 +139,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 DESCRIPTION
 
@@ -194,6 +195,16 @@ be available as a simple scalar:
         ]
     );
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Statocles::Help::Theme>
+
+=item L<Statocles::Theme>
+
+=back
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
