@@ -1,12 +1,26 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.033';
+$Statocles::Test::VERSION = '0.034';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
 use Test::Deep;
 use base qw( Exporter );
-our @EXPORT_OK = qw( test_constructor test_pages );
+our @EXPORT_OK = qw( test_constructor test_pages build_test_site );
+
+
+sub build_test_site {
+    my ( %site_args ) = @_;
+    require Statocles::Site;
+
+    return Statocles::Site->new(
+        title => 'Example Site',
+        base_url => 'http://example.com/',
+        build_store => Path::Tiny->tempdir,
+        deploy => Path::Tiny->tempdir,
+        %site_args,
+    );
+}
 
 
 sub test_constructor {
@@ -123,10 +137,18 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SUBROUTINES
 
+=head2 build_test_site( %site_args )
+
+Build a site for testing. The build and deploy will be set correctly to temporary
+directories. C<%site_args> will be given to the L<Statocles::Site|Statocles::Site>
+constructor.
+
+You must provide a C<theme> (probably using the one in C<t/share/theme>).
+
 =head2 test_constructor( class, args )
 
 Test an object constructor. C<class> is the class to test. C<args> is a list of
