@@ -1,6 +1,6 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.033';
+$Statocles::Theme::VERSION = '0.034';
 use Statocles::Base 'Class';
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
@@ -36,8 +36,20 @@ around BUILDARGS => sub {
 
 sub read {
     my ( $self, $app, $template ) = @_;
-    my $path = Path::Tiny->new( $app, $template . ".ep" );
-    my $content = $self->store->read_file( $path );
+    $template .= '.ep';
+    my $path = Path::Tiny->new( $app, $template );
+
+    my $content = eval { $self->store->read_file( $path ); };
+    if ( $@ ) {
+        if ( blessed $@ && $@->isa( 'Path::Tiny::Error' ) && $@->{op} =~ /^open/ ) {
+            die sprintf 'ERROR: Template "%s/%s" does not exist in theme directory "%s"' . "\n",
+                $app, $template, $self->store->path;
+        }
+        else {
+            die $@;
+        }
+    }
+
     return Statocles::Template->new(
         path => $path,
         content => $content,
@@ -63,7 +75,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
@@ -115,6 +127,16 @@ L<template|Statocles::Template> object.
 Get the L<template|Statocles::Template> from the given C<section> with the
 given C<name>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Statocles::Help::Theme>
+
+=item L<Statocles::Template>
+
+=back
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
